{#-
  This file was automatically generated - do not edit
-#}
{% import "partials/language.html" as lang with context %}
<!doctype html>
<html lang="{{ lang.t('language') }}" class="no-js">
  <head>
    {% block site_meta %}
      <meta charset="utf-8">
      <meta name="viewport" content="width=device-width,initial-scale=1">
      {% if page and page.meta and page.meta.description %}
        <meta name="description" content="{{ page.meta.description }}">
      {% elif config.site_description %}
        <meta name="description" content="{{ config.site_description }}">
      {% endif %}
      {% if page and page.meta and page.meta.keywords %}
        <meta name="keywords" content="{{ page.meta.keywords }}">
      {% elif config.site_keywords %}
        <meta name="keywords" content="{{ config.site_keywords }}">
      {% endif %}
      {% if page.canonical_url %}
        <link rel="canonical" href="{{ page.canonical_url }}">
      {% endif %}
      {% if page and page.meta and page.meta.author %}
        <meta name="author" content="{{ page.meta.author }}">
      {% elif config.site_author %}
        <meta name="author" content="{{ config.site_author }}">
      {% endif %}
      {% set favicon_type = config.theme.favicon_type or "image/x-icon" %}
      {% if config and config.theme and config.theme.favicon %}
        <link rel="shortcut icon" href="{{ config.theme.favicon | url }}" type="{{ favicon_type }}">
      {% endif %}
      {% if config.product == "proxy" %}
        <link rel="shortcut icon" href="{{ 'assets/images/logo-traefik-proxy-icon.svg' | url }}" type="image/svg+xml">
      {% elif config.product == "enterprise" %}
        <link rel="shortcut icon" href="{{ 'assets/images/logo-traefik-enterprise-icon.svg' | url }}" type="image/svg+xml">
      {% elif config.product == "mesh" %}
        <link rel="shortcut icon" href="{{ 'assets/images/logo-traefik-mesh-icon.svg' | url }}" type="image/svg+xml">
      {% endif %}
      <meta name="generator" content="mkdocs-{{ mkdocs_version }}, mkdocs-traefiklabs-100.0.22">
    {% endblock %}
    {% block htmltitle %}
      {% if page and page.meta and page.meta.title %}
        <title>{{ page.meta.title }} - {{ config.site_name }}</title>
      {% elif page and page.title and not page.is_homepage %}
        <title>{{ page.title | striptags }} - {{ config.site_name }}</title>
      {% else %}
        <title>{{ config.site_name }}</title>
      {% endif %}
    {% endblock %}
    {% block styles %}
      <link rel="stylesheet" href="{{ 'assets/stylesheets/main.30729de0.min.css' | url }}">
      {% if config.theme.palette %}
        {% set palette = config.theme.palette %}
        <link rel="stylesheet" href="{{ 'assets/stylesheets/palette.bd9ced1d.min.css' | url }}">
        {% if palette.primary %}
          {% import "partials/palette.html" as map %}
          {% set primary = map.primary(
            palette.primary | replace(" ", "-") | lower
          ) %}
          <meta name="theme-color" content="{{ primary }}">
        {% endif %}
      {% endif %}
    {% endblock %}
    {% block libs %}{% endblock %}
    {% block fonts %}
      {% if config.theme.font != false %}
        {% set font = config.theme.font %}
        <link href="https://fonts.gstatic.com" rel="preconnect" crossorigin>
        <link rel="stylesheet" href="https://fonts.googleapis.com/css?family={{
            font.text | replace(' ', '+') + ':300,400,400i,700%7C' +
            font.code | replace(' ', '+')
          }}&display=fallback">
        <style>body,input{font-family:"{{ font.text }}",-apple-system,BlinkMacSystemFont,Helvetica,Arial,sans-serif}code,kbd,pre{font-family:"{{ font.code }}",SFMono-Regular,Consolas,Menlo,monospace}</style>
      {% endif %}
    {% endblock %}
    {% if config.extra.manifest %}
      <link rel="manifest" href="{{ config.extra.manifest | url }}" crossorigin="use-credentials">
    {% endif %}
    {% for path in config["extra_css"] %}
      <link rel="stylesheet" href="{{ path | url }}">
    {% endfor %}
    {% block analytics %}
      <script>!function(e,t,a,n){e[n]=e[n]||[],e[n].push({"gtm.start":(new Date).getTime(),event:"gtm.js"});var g=t.getElementsByTagName(a)[0],m=t.createElement(a);m.async=!0,m.src="https://www.googletagmanager.com/gtm.js?id=GTM-NMWC63S",g.parentNode.insertBefore(m,g)}(window,document,"script","dataLayer")</script>
    {% endblock %}
    {% block extrahead %}{% endblock %}
    <script src="https://traefik.github.io/traefiklabs-header-app/main-v1.js"></script>
  </head>
  {% set direction = config.theme.direction or lang.t('direction') %}
  {% if config.theme.palette %}
    {% set palette = config.theme.palette %}
    {% if not palette is mapping %}
      {% set palette = palette | first %}
    {% endif %}
    {% set scheme  = palette.scheme  | replace(" ", "-") | lower %}
    {% set primary = palette.primary | replace(" ", "-") | lower %}
    {% set accent  = palette.accent  | replace(" ", "-") | lower %}
    <body dir="{{ direction }}" data-md-color-scheme="{{ scheme }}" data-md-color-primary="{{ primary }}" data-md-color-accent="{{ accent }}">
      {% if "preference" == scheme %}
        <script>matchMedia("(prefers-color-scheme: dark)").matches&&document.body.setAttribute("data-md-color-scheme","slate")</script>
      {% endif %}
  {% else %}
    <body dir="{{ direction }}">
  {% endif %}
    <input class="md-toggle" data-md-toggle="drawer" type="checkbox" id="__drawer" autocomplete="off">
    <input class="md-toggle" data-md-toggle="search" type="checkbox" id="__search" autocomplete="off">
    <label class="md-overlay" for="__drawer"></label>
    <div data-md-component="skip">
      {% if page.toc | first is defined %}
        {% set skip = page.toc | first %}
        <a href="{{ skip.url | url }}" class="md-skip">
          {{ lang.t('skip.link.title') }}
        </a>
      {% endif %}
    </div>
    {% block header %}
      {% include "partials/company-header.html" %}
    {% endblock %}
    <div class="md-container" data-md-component="container">
      <main class="md-main" data-md-component="main">
        <div class="md-main__inner md-grid">
          {% block site_nav %}
            {% if nav %}
              <div class="md-sidebar md-sidebar--primary">
                {% include "partials/product-switcher.html" %}
                {% if "search" in config["plugins"] %}
                  {% include "partials/search.html" %}
                  <label class="md-icon md-icon--search md-header-nav__button" for="__search"></label>
                {% endif %}
                <div class="md-sidebar__scrollwrap" data-md-component="navigation">
                  <div class="md-sidebar__inner">
                  {% include "partials/nav.html" %}
                  </div>
                </div>
              </div>
            {% endif %}
            {% if page.toc %}
              <div class="md-sidebar md-sidebar--secondary">
                {% if config.repo_url %}
                  <div class="md-flex__cell md-flex__cell--shrink repo_url">
                    <div class="md-header-nav__source">
                      {% include "partials/source.html" %}
                    </div>
                  </div>
                {% endif %}
                <div class="md-sidebar__scrollwrap" data-md-component="toc">
                  <div class="md-sidebar__inner">
                    {% include "partials/toc.html" %}
                  </div>
                </div>
              </div>
            {% endif %}
          {% endblock %}
          <div class="md-content">
            <article class="md-content__inner md-typeset">
              {% block content %}
                {% if page.edit_url %}
                  <a href="{{ page.edit_url }}" title="{{ lang.t('edit.link.title') }}" class="md-content__button md-icon">
                    {% include ".icons/material/pencil.svg" %}
                  </a>
                {% endif %}
                {% if not "\x3ch1" in page.content %}
                  <h1>{{ page.title | default(config.site_name, true)}}</h1>
                {% endif %}
                {{ page.content }}
                {% if page and page.meta %}
                  {% if page.meta.git_revision_date_localized or
                        page.meta.revision_date
                  %}
                    {% include "partials/source-date.html" %}
                  {% endif %}
                {% endif %}
              {% endblock %}
              {% block disqus %}
                {% include "partials/integrations/disqus.html" %}
              {% endblock %}
            </article>
          </div>
        </div>
      </main>
      {% block footer %}
        {% include "partials/footer.html" %}
      {% endblock %}
    </div>
    {% block scripts %}
      <script src="{{ 'assets/javascripts/vendor.08c56446.min.js' | url }}"></script>
      <script src="{{ 'assets/javascripts/bundle.35864de0.min.js' | url }}"></script>
      {%- set translations = {} -%}
      {%- for key in [
        "clipboard.copy",
        "clipboard.copied",
        "search.config.lang",
        "search.config.pipeline",
        "search.config.separator",
        "search.placeholder",
        "search.result.placeholder",
        "search.result.none",
        "search.result.one",
        "search.result.other",
        "search.result.more.one",
        "search.result.more.other",
        "search.result.term.missing"
      ] -%}
        {%- set _ = translations.update({ key: lang.t(key) }) -%}
      {%- endfor -%}
      <script id="__lang" type="application/json">
        {{- translations | tojson -}}
      </script>
      {% block config %}{% endblock %}
      <script>
        app = initialize({
          base: "{{ base_url }}",
          features: {{ config.theme.features or [] | tojson }},
          search: Object.assign({
            worker: "{{ 'assets/javascripts/worker/search.1866c2a5.min.js' | url }}"
          }, typeof search !== "undefined" && search)
        })
      </script>
      {% for path in config["extra_javascript"] %}
        <script src="{{ path | url }}"></script>
      {% endfor %}
    {% endblock %}
  </body>
</html>
