{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "si",
  "clipboard.copy": "Kopiraj v odložišče",
  "clipboard.copied": "Kopirano v odložišče",
  "edit.link.title": "Uredi stran",
  "footer.previous": "Prejšnja stran",
  "footer.next": "Naslednja stran",
  "meta.comments": "Komentarji",
  "meta.source": "Izvorna koda",
  "search.placeholder": "Išči",
  "search.result.placeholder": "Vpiši iskalni niz",
  "search.result.none": "Ni zadetkov",
  "search.result.one": "1 zadetek",
  "search.result.other": "# zadetkov",
  "skip.link.title": "Skoči na vsebino",
  "source.link.title": "Pojdi na repozitorij",
  "source.revision.date": "Zadnja posodobitev",
  "toc.title": "Kazalo"
}[key] }}{% endmacro %}
