{#-
  This file was automatically generated - do not edit
-#}
{% import "partials/language.html" as lang with context %}
{% set label = lang.t("source.revision.date") %}
<hr>
<div class="md-source-date">
  <small>
    {% if page.meta.git_revision_date_localized %}
      {{ label }}: {{ page.meta.git_revision_date_localized }}
    {% elif page.meta.revision_date %}
      {{ label }}: {{ page.meta.revision_date }}
    {% endif %}
  </small>
</div>
