{#-
  This file was automatically generated - do not edit
-#}
<header class="md-header">
  {% include "partials/search.html" %}
</header>
<div style="height:64px"></div>
<header-app></header-app>
<div class="header-container__mobile"></div>
<label class="md-icon md-icon--menu md-header-nav__button" for="__drawer">
  {% include ".icons/material/menu" ~ ".svg" %}
</label>