{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "et",
  "clipboard.copy": "Kopeeri lõikelauale",
  "clipboard.copied": "Kopeeritud",
  "edit.link.title": "Muuda seda lehte",
  "footer.previous": "Eelmine",
  "footer.next": "Järgmine",
  "meta.comments": "Kommentaarid",
  "meta.source": "Lähtekood",
  "search.placeholder": "Otsi",
  "search.result.placeholder": "Otsimiseks kirjuta siia",
  "search.result.none": "Otsingule ei leitud ühtegi vastet",
  "search.result.one": "Leiti üks tulemus",
  "search.result.other": "Leiti # tulemust",
  "skip.link.title": "Keri sisuni",
  "source.link.title": "Ava repositooriumis",
  "source.revision.date": "Viimane uuendus",
  "toc.title": "Sisukord"
}[key] }}{% endmacro %}
