{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "sv",
  "clipboard.copy": "Kopiera till urklipp",
  "clipboard.copied": "Kopierat till urklipp",
  "edit.link.title": "Redigera sidan",
  "footer.previous": "Föregående",
  "footer.next": "Nästa",
  "footer.title": "Sidfot",
  "header.title": "Sidhuvud",
  "meta.comments": "Kommentarer",
  "meta.source": "Källa",
  "nav.title": "Navigation",
  "search.config.lang": "sv",
  "search.placeholder": "Sök",
  "search.reset": "Rensa",
  "search.result.initializer": "Initialiserar sök",
  "search.result.placeholder": "Skriv sökord",
  "search.result.none": "Inga sökresultat",
  "search.result.one": "1 sökresultat",
  "search.result.other": "# sökresultat",
  "search.result.more.one": "1 till på denna sidan",
  "search.result.more.other": "# till på denna sidan",
  "search.result.term.missing": "Saknas",
  "skip.link.title": "Gå till innehållet",
  "source.link.title": "Gå till datakatalog",
  "source.revision.date": "Senaste uppdateringen",
  "tabs.title"; "Flikar",
  "toc.title": "Innehållsförteckning"
}[key] }}{% endmacro %}
