{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "cs",
  "clipboard.copy": "Kopírovat do schránky",
  "clipboard.copied": "Zkopírováno do schránky",
  "edit.link.title": "Upravit tuto stránku",
  "footer.previous": "Předchozí",
  "footer.next": "Další",
  "meta.comments": "Komentáře",
  "meta.source": "Zdroj",
  "search.placeholder": "Hledat",
  "search.result.placeholder": "Pište co se má vyhledat",
  "search.result.none": "Nenalezeny žádné dokumenty",
  "search.result.one": "Nalezený dokument: 1",
  "search.result.other": "Nalezené dokumenty: #",
  "skip.link.title": "Přeskočit obsah",
  "source.link.title": "Přejít do repozitáře",
  "source.revision.date": "Poslední aktualizace",
  "toc.title": "Obsah"
}[key] }}{% endmacro %}
