{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "nl",
  "clipboard.copy": "Kopiëren naar klembord",
  "clipboard.copied": "Gekopieerd naar klembord",
  "edit.link.title": "Wijzig deze pagina",
  "footer.previous": "Vorige",
  "footer.next": "Volgende",
  "meta.comments": "Reacties",
  "meta.source": "Bron",
  "search.config.lang": "nl",
  "search.placeholder": "Zoeken",
  "search.result.placeholder": "Typ om te beginnen met zoeken",
  "search.result.none": "Geen overeenkomende documenten",
  "search.result.one": "1 overeenkomende document",
  "search.result.other": "# overeenkomende documenten",
  "skip.link.title": "Ga naar inhoud",
  "source.link.title": "Ga naar repository",
  "source.revision.date": "Laatst geüpdatet op",
  "toc.title": "Inhoudsopgave"
}[key] }}{% endmacro %}
