{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "it",
  "clipboard.copy": "Copia",
  "clipboard.copied": "Copiato",
  "edit.link.title": "Modifica",
  "footer.previous": "Precedente",
  "footer.next": "Prossimo",
  "meta.comments": "Commenti",
  "meta.source": "Sorgente",
  "search.config.lang": "it",
  "search.placeholder": "Cerca",
  "search.result.placeholder": "Scrivi per iniziare a cercare",
  "search.result.none": "Nessun documento trovato",
  "search.result.one": "1 documento trovato",
  "search.result.other": "# documenti trovati",
  "skip.link.title": "Vai al contenuto",
  "source.link.title": "Apri repository",
  "source.revision.date": "Ultimo aggiornamento",
  "toc.title": "Indice"
}[key] }}{% endmacro %}
