{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "gr",
  "clipboard.copy": "Αντιγραφή",
  "clipboard.copied": "Αντιγράφηκε",
  "edit.link.title": "Επεξεργασία αυτής της σελίδας",
  "footer.previous": "Επόμενη",
  "footer.next": "Προηγούμενη",
  "meta.comments": "Σχόλια",
  "meta.source": "Πηγή",
  "search.config.pipeline": " ",
  "search.placeholder": "Αναζήτηση",
  "search.result.placeholder": "Πληκτρολογήστε για να αρχίσει η αναζήτηση",
  "search.result.none": "Δε βρέθηκαν αντίστοιχα αρχεία",
  "search.result.one": "1 αντίστοιχο αρχείο",
  "search.result.other": "# αντίστοιχα αρχεία",
  "skip.link.title": "Μετάβαση στο περιεχόμενο",
  "source.link.title": "Μετάβαση στο αποθετήριο",
  "source.revision.date": "τελευταία ενημέρωση",
  "toc.title": "Πίνακας περιεχομένων"
}[key] }}{% endmacro %}
